package mvc;

import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JList;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

public class AddControler implements ActionListener, DocumentListener {
	        private boolean alreadyEnabled = false;
	        private JButton button;
	        private JTextField fruitName;
	    	DefaultListModel model;
	    	JList view;


	        public AddControler(JButton button, JTextField fruitName,DefaultListModel model, JList view) {
	            this.button = button;
	    		this.model = model;
	    		this.view = view;
	            this.fruitName = fruitName;
	        }
	        //Required by ActionListener.
	        public void actionPerformed(ActionEvent e) {
	            String name = fruitName.getText();

	            //User didn't type in a unique name...
	            if (name.equals("") || alreadyInList(name)) {
	                Toolkit.getDefaultToolkit().beep();
	                fruitName.requestFocusInWindow();
	                fruitName.selectAll();
	                return;
	            }

	            int index = view.getSelectedIndex(); //get selected index
	            if (index == -1) { //no selection, so insert at beginning
	                index = 0;
	            } else {           //add after the selected item
	                index++;
	            }

	            model.insertElementAt(fruitName.getText(), index);
	            //If we just wanted to add to the end, we'd do this:
	            //listModel.addElement(employeeName.getText());

	            //Reset the text field.
	            fruitName.requestFocusInWindow();
	            fruitName.setText("");

	            //Select the new item and make it visible.
	            view.setSelectedIndex(index);
	            view.ensureIndexIsVisible(index);
	        }

	        //This method tests for string equality. You could certainly
	        //get more sophisticated about the algorithm.  For example,
	        //you might want to ignore white space and capitalization.
	        protected boolean alreadyInList(String name) {
	            return model.contains(name);
	        }

	        //Required by DocumentListener.
	        public void insertUpdate(DocumentEvent e) {
	            enableButton();
	        }

	        //Required by DocumentListener.
	        public void removeUpdate(DocumentEvent e) {
	            handleEmptyTextField(e);
	        }

	        //Required by DocumentListener.
	        public void changedUpdate(DocumentEvent e) {
	            if (!handleEmptyTextField(e)) {
	                enableButton();
	            }
	        }

	        private void enableButton() {
	            if (!alreadyEnabled) {
	                button.setEnabled(true);
	            }
	        }

	        private boolean handleEmptyTextField(DocumentEvent e) {
	            if (e.getDocument().getLength() <= 0) {
	                button.setEnabled(false);
	                alreadyEnabled = false;
	                return true;
	            }
	            return false;
	        }
	    }
